@@ -15,7 +15,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
 
-our $VERSION = '0.4';
+our $VERSION = '0.5';
 
 =head1 NAME
 
@@ -136,6 +136,8 @@ sub end_element {
         if ( $element =~ /(integer|string|date)/ ) {
             $item->{$curKey} = $characters;
             $characters = undef;
+        } elsif ( $element =~ /true/ ) {
+            $item->{$curKey} = 1;
         }
     }
 } #end_element
@@ -222,8 +224,8 @@ Drew Stephens <drew@dinomite.net>, http://dinomite.net
 
 =head1 SVN INFO
 
-$Revision: 61 $
-$Date: 2009-04-27 22:40:34 -0700 (Mon, 27 Apr 2009) $
+$Revision: 67 $
+$Date: 2009-05-03 22:31:22 -0700 (Sun, 03 May 2009) $
 $Author: drewgstephens $
 
 =head1 COPYRIGHT AND LICENSE
